==> databene-benerator-0.7.7-sources.jar: org/databene/benerator/engine/statement/SetSettingStatement.java <==
/*
 * (c) Copyright 2009-2011 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License.
 *
 * For redistributing this software or a derivative work under a license other
 * than the GPL-compatible Free Software License as defined by the Free
 * Software Foundation or approved by OSI, you must first obtain a commercial
 * license to this software product from Volker Bergmann.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.benerator.engine.statement;

import org.databene.benerator.engine.BeneratorContext;
import org.databene.benerator.engine.Statement;
import org.databene.commons.mutator.AnyMutator;
import org.databene.script.Expression;
import org.databene.script.expression.ExpressionUtil;

/**
 * Sets a global Benerator property.<br/>
 * <br/>
 * Created at 23.07.2009 14:50:08
 * @since 0.6.0
 * @author Volker Bergmann
 */

public class SetSettingStatement implements Statement {
	
	private String propertyName;
	private Expression<?> valueExpression;

    public SetSettingStatement(String propertyName, Expression<?> valueExpression) {
    	this.propertyName = propertyName;
    	this.valueExpression = valueExpression;
    }

	public boolean execute(BeneratorContext context) {
        Object value = ExpressionUtil.evaluate(valueExpression, context);
		if (propertyName.startsWith("context."))
	        AnyMutator.setValue(context, propertyName, value, true);
        else {
			context.setSetting(propertyName, value);
        }
    	return true;
	}

}

==> databene-benerator-0.9.8-sources.jar: org/databene/benerator/engine/statement/SetSettingStatement.java <==
/*
 * (c) Copyright 2009-2013 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License.
 *
 * For redistributing this software or a derivative work under a license other
 * than the GPL-compatible Free Software License as defined by the Free
 * Software Foundation or approved by OSI, you must first obtain a commercial
 * license to this software product from Volker Bergmann.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.benerator.engine.statement;

import org.databene.benerator.engine.BeneratorContext;
import org.databene.benerator.engine.Statement;
import org.databene.commons.mutator.AnyMutator;
import org.databene.script.Expression;
import org.databene.script.expression.ExpressionUtil;

/**
 * Sets a global Benerator property.<br/>
 * <br/>
 * Created at 23.07.2009 14:50:08
 * @since 0.6.0
 * @author Volker Bergmann
 */

public class SetSettingStatement implements Statement {
	
	private String propertyName;
	private Expression<?> valueExpression;

    public SetSettingStatement(String propertyName, Expression<?> valueExpression) {
    	this.propertyName = propertyName;
    	this.valueExpression = valueExpression;
    }

	@Override
	public boolean execute(BeneratorContext context) {
        Object value = ExpressionUtil.evaluate(valueExpression, context);
		if (propertyName.startsWith("context."))
	        AnyMutator.setValue(context, propertyName, value, true, true);
        else {
			context.setGlobal(propertyName, value);
        }
    	return true;
	}

}
